require("./babel.js");
require("./comments.js");
require("./es6tests.js");
require("./identity.js");
require("./jsx.js");
require("./lines.js");
require("./mapping.js");
require("./parens.js");
require("./parser.js");
require("./patcher.js");
require("./perf.js");
require("./printer.js");
require("./syntax.js");
require("./type-syntax.js");
require("./typescript.js");
require("./visit.js");
